#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-smallcheck
version:              0.5.3
visibility:           public
id:                   hspec-smallcheck-0.5.3-AJaPDwCeaDm46ETrLMXE7j
key:                  hspec-smallcheck-0.5.3-AJaPDwCeaDm46ETrLMXE7j
license:              MIT
copyright:            (c) 2013-2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
homepage:             http://hspec.github.io/
synopsis:             SmallCheck support for the Hspec testing framework
description:          SmallCheck support for the Hspec testing framework
category:             Testing
abi:                  b5276bcf870f4547e5a45e94d684e255
exposed:              True
exposed-modules:      Test.Hspec.SmallCheck
hidden-modules:
    Test.Hspec.SmallCheck.Compat Test.Hspec.SmallCheck.Types
    Paths_hspec_smallcheck

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-smallcheck-0.5.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-smallcheck-0.5.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-smallcheck-0.5.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-smallcheck
hs-libraries:         HShspec-smallcheck-0.5.3-AJaPDwCeaDm46ETrLMXE7j
depends:
    HUnit-1.6.2.0-AT4Mx0wk6OXAfe1KUqjGNi base-4.18.2.1
    call-stack-0.4.0-Cy9xJTJdicU5c9ivm2ABko
    hspec-core-2.11.6-INlxYvz6hFX69G4gg8sgu9
    smallcheck-1.2.1.1-22IgTyJjmf21mZThjqIUT2

haddock-interfaces:
    /usr/share/doc/haskell-hspec-smallcheck/html/hspec-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-hspec-smallcheck/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

